@@ -7,12 +7,15 @@ use common::{
 use expect_test::expect;
 use maturin::pyproject_toml::SdistGenerator;
 use rstest::rstest;
+use serial_test::serial;
 use std::env;
 use std::path::Path;
 use std::time::Duration;
 use time::macros::datetime;
 use which::which;
 
+use crate::common::{find_subslice, pep517};
+
 mod common;
 
 #[test]
@@ -648,11 +651,11 @@ fn workspace_members_non_local_dep_sdist() {
         edition = "2021"
         description = "Implements a dummy function (get_fortytwo.DummyClass.get_42()) in rust"
         license = "MIT"
+        readme = "README.md"
 
         [dependencies]
-        pyo3 = { version = "0.25.0", features = [
+        pyo3 = { version = "0.27.0", features = [
             "abi3-py37",
-            "extension-module",
             "generate-import-lib",
         ] }
 
@@ -719,7 +722,7 @@ fn lib_with_target_path_dep_sdist() {
         crate-type = ["cdylib"]
 
         [dependencies]
-        pyo3 = { version = "0.25.0", features = ["extension-module"] }
+        pyo3 = "0.27.0"
 
         [target.'cfg(not(target_endian = "all-over-the-place"))'.dependencies]
         some_path_dep = { path = "../some_path_dep" }
@@ -935,12 +938,37 @@ fn workspace_inheritance_sdist() {
     ))
 }
 
+#[test]
+fn workspace_license_files() {
+    handle_result(other::test_source_distribution(
+        "test-crates/hello-world",
+        SdistGenerator::Cargo,
+        expect![[r#"
+            {
+                "hello_world-0.1.0/Cargo.lock",
+                "hello_world-0.1.0/Cargo.toml",
+                "hello_world-0.1.0/LICENSE",
+                "hello_world-0.1.0/PKG-INFO",
+                "hello_world-0.1.0/README.md",
+                "hello_world-0.1.0/check_installed/check_installed.py",
+                "hello_world-0.1.0/licenses/AUTHORS.txt",
+                "hello_world-0.1.0/pyproject.toml",
+                "hello_world-0.1.0/src/bin/foo.rs",
+                "hello_world-0.1.0/src/main.rs",
+            }
+        "#]],
+        None,
+        "sdist-hello-world",
+    ))
+}
+
 #[test]
 fn abi3_python_interpreter_args() {
     handle_result(other::abi3_python_interpreter_args());
 }
 
 #[test]
+#[serial(source_date_epoch_env)]
 fn pyo3_source_date_epoch() {
     env::set_var("SOURCE_DATE_EPOCH", "0");
     handle_result(other::check_wheel_mtimes(
@@ -949,3 +977,57 @@ fn pyo3_source_date_epoch() {
         "pyo3_source_date_epoch",
     ))
 }
+
+#[test]
+#[serial(source_date_epoch_env)]
+fn sdist_no_source_date_epoch() {
+    env::remove_var("SOURCE_DATE_EPOCH");
+    handle_result(other::check_sdist_mtimes(
+        "test-crates/pyo3-mixed-include-exclude",
+        1153704088,
+        "sdist_no_source_date_epoch",
+    ))
+}
+
+#[test]
+#[serial(source_date_epoch_env)]
+fn sdist_source_date_epoch() {
+    env::set_var("SOURCE_DATE_EPOCH", "1");
+    handle_result(other::check_sdist_mtimes(
+        "test-crates/pyo3-mixed-include-exclude",
+        1,
+        "sdist_source_date_epoch",
+    ))
+}
+
+#[test]
+fn pep517_default_profile() {
+    let output = handle_result(pep517::test_pep517(
+        "test-crates/pyo3-pure",
+        "pep517-pyo3-pure",
+        false,
+        false,
+    ));
+
+    assert!(
+        find_subslice(&output.stderr, b"`release` profile [optimized]").is_some(),
+        "Output was: {}",
+        std::str::from_utf8(&output.stderr).unwrap()
+    );
+}
+
+#[test]
+fn pep517_editable_profile() {
+    let output = handle_result(pep517::test_pep517(
+        "test-crates/pyo3-pure",
+        "pep517-pyo3-pure-editable",
+        false,
+        true,
+    ));
+
+    assert!(
+        find_subslice(&output.stderr, b"`dev` profile [unoptimized + debuginfo]").is_some(),
+        "Output was: {}",
+        std::str::from_utf8(&output.stderr).unwrap()
+    );
+}
